==> nextcloud-29.0.12.tgz: nextcloud/apps/password_policy/l10n/ga.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Tá an pasfhocal imithe in éag, le do thoil bain úsáid as modh pasfhocal dearmadta chun athshocrú",
    "Password must not have been used recently before." : "Níor cheart gur úsáideadh pasfhocal le déanaí roimhe seo.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Tá pasfhocal i measc na 1,000,000 ceann is coitianta. Déan uathúil é le do thoil.",
    "Password is present in compromised password list. Please choose a different password." : "Tá pasfhocal i láthair sa liosta pasfhocal i mbaol. Roghnaigh pasfhocal eile le do thoil.",
    "Password needs to be at least %s characters long." : "Ní mór do phasfhocail a bheith %s carachtair fada.",
    "Password needs to contain at least one numeric character." : "Caithfidh carachtar uimhriúil amháin ar a laghad a bheith sa phasfhocal.",
    "Password needs to contain at least one special character." : "Caithfidh carachtar speisialta amháin ar a laghad a bheith sa phasfhocal.",
    "Password needs to contain at least one lower and one upper case character." : "Caithfidh carachtar cás íochtair amháin agus cás uachtair amháin ar a laghad a bheith sa phasfhocal.",
    "Password policy" : "Polasaí pasfhocail",
    "Allows admins to configure a password policy" : "Ligeann sé do riarthóirí polasaí pasfhocail a chumrú",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Lig don riarthóir réamhchoinníollacha áirithe a shainiú le haghaidh pasfhocail, m.sh. íosfhad a fhorfheidhmiú",
    "General password policies" : "Polasaithe pasfhocail ginearálta",
    "Add policy set" : "Cuir tacar polasaí leis",
    "Login policies" : "Beartais logáil isteach",
    "Password history size" : "Méid stair phasfhocal",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Líon na bhfocal faire le coinneáil (suíomh go sábháilte) chun cosc ​​a chur ar úsáideoirí pasfhocail a úsáideadh roimhe seo a athúsáid.",
    "Maximum login attempts" : "Uasiarrachtaí logáil isteach",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Díchumasófar líon na n-iarrachtaí logáil isteach roimh an gcuntas úsáideora go dtí go ndéanfar gníomh de láimh. (0 gan teorainn)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Tabhair faoi deara, tá an rogha seo i gceist chun cuntais ionsaithe a chosaint. Ní mór don riarachán cuntais míchumasaithe a athchumasú de láimh. Ionsaitheoirí a dhéanann iarracht pasfhocail chuntas a thomhas, cuirfear bac ar a seoladh IP ag an gcosaint bruteforce neamhspleách ón socrú seo.",
    "Number of days until user password expires" : "Líon na laethanta go dtí go rachaidh pasfhocal úsáideora in éag",
    "Password expiration" : "Pasfhocal in éag",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Rabhadh: measann go leor gníomhaireachtaí slándála gur riosca slándála é ceadú dul in éag pasfhocail.",
    "Remove policy" : "Bain polasaí",
    "Minimum password length" : "Íosfhad pasfhocail",
    "Forbid common passwords" : "Cosc ar phasfhocail choitianta",
    "Enforce upper and lower case characters" : "Cuir carachtair cás uachtair agus cás íochtair i bhfeidhm",
    "Enforce numeric characters" : "Cuir carachtair uimhriúla i bhfeidhm",
    "Enforce special characters" : "Forfheidhmigh carachtair speisialta",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Seiceáil an pasfhocal in aghaidh an liosta pasfhocail sáraithe ó haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Cruthaíonn an tseiceáil seo hash den fhocal faire agus seolann sé na chéad 5 charachtar den hash seo chuig an haveibeenpwned.com API chun liosta a fháil de na hashes ar fad a thosaíonn leo siúd. Ansin seiceálann sé ar an gcéad Nextcloud an bhfuil an hash pasfhocal sa tacar torthaí.",
    "Account password policies" : "Polasaithe pasfhocail cuntais",
    "Share password policies" : "Roinn polasaithe pasfhocail",
    "User password history" : "Stair pasfhocail úsáideora",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Tabhair faoi deara, le do thoil, go bhfuil an rogha seo i gceist chun cuntais ionsaithe a chosaint. Ní mór don riarachán cuntais míchumasaithe a athchumasú de láimh. Ionsaitheoirí a dhéanann iarracht pasfhocail chuntas a thomhas, cuirfear bac ar a seoladh IP ag an gcosaint bruteforce neamhspleách ón socrú seo.",
    "Unknown error" : "Earráid anaithnid",
    "Minimal length has to be a non negative number" : "Caithfidh an t-íosfhad a bheith ina uimhir neamhdhiúltach",
    "History size has to be a non negative number" : "Caithfidh méid na staire a bheith ina uimhir neamhdhiúltach",
    "Expiration days have to be a non negative number" : "Caithfidh laethanta éaga a bheith ina uimhir neamhdhiúltach",
    "Maximum login attempts have to be a non negative number" : "Caithfidh na huasiarrachtaí logáil isteach a bheith ina n-uimhir neamhdhiúltach",
    "Settings saved" : "Socruithe sábháilte",
    "Error while saving settings" : "Earráid agus na socruithe á sábháil"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/password_policy/l10n/ga.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Tá an pasfhocal imithe in éag, le do thoil bain úsáid as modh pasfhocal dearmadta chun athshocrú",
    "Password must not have been used recently before." : "Níor cheart gur úsáideadh pasfhocal le déanaí roimhe seo.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Tá pasfhocal i measc na 1,000,000 ceann is coitianta. Déan uathúil é le do thoil.",
    "Password is present in compromised password list. Please choose a different password." : "Tá pasfhocal i láthair sa liosta pasfhocal i mbaol. Roghnaigh pasfhocal eile le do thoil.",
    "Password needs to be at least %s characters long." : "Ní mór do phasfhocail a bheith %s carachtair fada.",
    "Password needs to contain at least one numeric character." : "Caithfidh carachtar uimhriúil amháin ar a laghad a bheith sa phasfhocal.",
    "Password needs to contain at least one special character." : "Caithfidh carachtar speisialta amháin ar a laghad a bheith sa phasfhocal.",
    "Password needs to contain at least one lower and one upper case character." : "Caithfidh carachtar cás íochtair amháin agus cás uachtair amháin ar a laghad a bheith sa phasfhocal.",
    "Password policy" : "Polasaí pasfhocail",
    "Allows admins to configure a password policy" : "Ligeann sé do riarthóirí polasaí pasfhocail a chumrú",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Lig don riarthóir réamhchoinníollacha áirithe a shainiú le haghaidh pasfhocail, m.sh. íosfhad a fhorfheidhmiú",
    "Minimum password length" : "Íosfhad pasfhocail",
    "User password history" : "Stair pasfhocail úsáideora",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Díchumasófar líon na n-iarrachtaí logáil isteach roimh an gcuntas úsáideora go dtí go ndéanfar gníomh de láimh. (0 gan teorainn)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Tabhair faoi deara, tá an rogha seo i gceist chun cuntais ionsaithe a chosaint. Ní mór don riarachán cuntais míchumasaithe a athchumasú de láimh. Ionsaitheoirí a dhéanann iarracht pasfhocail chuntas a thomhas, cuirfear bac ar a seoladh IP ag an gcosaint bruteforce neamhspleách ón socrú seo.",
    "Number of days until user password expires" : "Líon na laethanta go dtí go rachaidh pasfhocal úsáideora in éag",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Rabhadh: measann go leor gníomhaireachtaí slándála gur riosca slándála é ceadú dul in éag pasfhocail.",
    "Forbid common passwords" : "Cosc ar phasfhocail choitianta",
    "Enforce upper and lower case characters" : "Cuir carachtair cás uachtair agus cás íochtair i bhfeidhm",
    "Enforce numeric characters" : "Cuir carachtair uimhriúla i bhfeidhm",
    "Enforce special characters" : "Forfheidhmigh carachtair speisialta",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Seiceáil an pasfhocal in aghaidh an liosta pasfhocail sáraithe ó haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Cruthaíonn an tseiceáil seo hash den fhocal faire agus seolann sé na chéad 5 charachtar den hash seo chuig an haveibeenpwned.com API chun liosta a fháil de na hashes ar fad a thosaíonn leo siúd. Ansin seiceálann sé ar an gcéad Nextcloud an bhfuil an hash pasfhocal sa tacar torthaí.",
    "Unknown error" : "Earráid anaithnid",
    "Minimal length has to be a non negative number" : "Caithfidh an t-íosfhad a bheith ina uimhir neamhdhiúltach",
    "History size has to be a non negative number" : "Caithfidh méid na staire a bheith ina uimhir neamhdhiúltach",
    "Expiration days have to be a non negative number" : "Caithfidh laethanta éaga a bheith ina uimhir neamhdhiúltach",
    "Maximum login attempts have to be a non negative number" : "Caithfidh na huasiarrachtaí logáil isteach a bheith ina n-uimhir neamhdhiúltach",
    "Settings saved" : "Socruithe sábháilte",
    "Error while saving settings" : "Earráid agus na socruithe á sábháil",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Tabhair faoi deara, le do thoil, go bhfuil an rogha seo i gceist chun cuntais ionsaithe a chosaint. Ní mór don riarachán cuntais míchumasaithe a athchumasú de láimh. Ionsaitheoirí a dhéanann iarracht pasfhocail chuntas a thomhas, cuirfear bac ar a seoladh IP ag an gcosaint bruteforce neamhspleách ón socrú seo."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
